-file("/usr/lib/erlang/lib/parsetools-2.1.8/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(pant_lexer).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("src/pant_lexer.xrl", 36).

integer(Chars) ->
    String = string:replace(Chars, "_", ""),
    {Int, []} = string:to_integer(String),
    Int.

to_float(Chars) ->
    {Float, []} = string:to_float(Chars),
    Float.

literal([$`|Chars]) -> literal(Chars, []);
literal(Chars) -> literal(Chars, []).

literal("`", Acc) -> string:reverse(Acc);
literal([], Acc) -> string:reverse(Acc);
literal([C|Chars], Acc) -> literal(Chars, [C|Acc]).

comment(Chars, TokenLine) ->
    Pushback = case string:find(Chars, "\n", trailing) of
        nomatch -> [];
        _ -> "\n"
    end,
    {token, {comment, TokenLine, string:trim(Chars, both, "\n\"\s")}, Pushback}.

keyword(Keyword, TokenLine) when
    Keyword == "and";
    Keyword == "xor";
    Keyword == "or"          -> {binary_operator, TokenLine, Keyword};
keyword("exists", TokenLine) -> {quantifier, TokenLine, exists};
keyword("all", TokenLine)    -> {quantifier, TokenLine, all};
keyword("fn", TokenLine)     -> {fn, TokenLine};
keyword("import", TokenLine) -> {import, TokenLine};
keyword("module", TokenLine) -> {module, TokenLine};
keyword("in", TokenLine)   -> {binary_operator, TokenLine, "in"};
keyword(Chars, TokenLine)    -> {symbol, TokenLine, Chars}.

operator("::", TokenLine) -> {yield_type, TokenLine, "::"};
operator("=>", TokenLine) -> {yield_type, TokenLine, "=>"};
operator("<-", TokenLine) -> {refined, TokenLine};
operator(":", TokenLine)  -> {':', TokenLine};
operator("<=", TokenLine) -> {reverse_yield, TokenLine};
operator(TokenChars, TokenLine) when
    TokenChars == "+";
    TokenChars == "*";
    TokenChars == "-";
    TokenChars == "%";
    TokenChars == "=";
    TokenChars == "!=";
    TokenChars == ">";
    TokenChars == "<";
    TokenChars == ">=";
    TokenChars == "=<";
    TokenChars == "->";
    TokenChars == "<->";
    TokenChars == "^";
    TokenChars == "&";
    TokenChars == ":?";
    TokenChars == "|"     -> {binary_operator, TokenLine, TokenChars};
operator(TokenChars, TokenLine) when
    TokenChars == "~";
    TokenChars == "#"     -> {unary_operator, TokenLine, TokenChars}.

-file("/usr/lib/erlang/lib/parsetools-2.1.8/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transistion state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,Tlen,_Ics1,L1,_S1} ->
            Tcs1 = yysuf(Tcs, Alen),
            L2 = adjust_line(Tlen, Alen, Tcs1, L1),
            string_cont(Tcs1, L2, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

-dialyzer({nowarn_function, string_cont/4}).

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->       % Use last accept match
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            token_cont(Tcs1, L2, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

-dialyzer({nowarn_function, token_cont/3}).

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            tokens_cont(Tcs1, L2, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

-dialyzer({nowarn_function, tokens_cont/4}).

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            skip_cont(Tcs1, L2, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

-dialyzer({nowarn_function, skip_cont/4}).

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

-compile({nowarn_unused_function, [yyrev/1, yyrev/2, yypre/2, yysuf/2]}).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% adjust_line(TokenLength, AcceptLength, Chars, Line) -> NewLine
%% Make sure that newlines in Chars are not counted twice.
%% Line has been updated with respect to newlines in the prefix of
%% Chars consisting of (TokenLength - AcceptLength) characters.

-compile({nowarn_unused_function, adjust_line/4}).

adjust_line(N, N, _Cs, L) -> L;
adjust_line(T, A, [$\n|Cs], L) ->
    adjust_line(T-1, A, Cs, L-1);
adjust_line(T, A, [_|Cs], L) ->
    adjust_line(T-1, A, Cs, L).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("src/pant_lexer.erl", 368).
yystate() -> 40.

yystate(43, [95|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [46|Ics], Line, Tlen, _, _) ->
    yystate(41, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(43, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 96, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(43, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line,43};
yystate(42, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(42, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,42};
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(41, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,41};
yystate(40, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [96|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [94|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [90|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [89|Ics], Line, Tlen, Action, Alen) ->
    yystate(16, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [61|Ics], Line, Tlen, Action, Alen) ->
    yystate(27, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [60|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(17, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [41|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [38|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [37|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [36|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line+1, Tlen+1, Action, Alen);
yystate(40, [9|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 8 ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 88 ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [C|Ics], Line, Tlen, Action, Alen) when C >= 91, C =< 93 ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [C|Ics], Line, Tlen, Action, Alen) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(40, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,40};
yystate(39, [58|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 10, Tlen);
yystate(39, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,39};
yystate(38, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [32|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [10|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line+1, Tlen+1, 7, Tlen);
yystate(38, [9|Ics], Line, Tlen, _, _) ->
    yystate(38, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 7, Tlen);
yystate(38, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,38};
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(37, Ics, Line, Tlen+1, 2, Tlen);
yystate(37, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,37};
yystate(36, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line};
yystate(35, [62|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 10, Tlen);
yystate(35, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,35};
yystate(34, [59|Ics], Line, Tlen, _, _) ->
    yystate(38, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [32|Ics], Line, Tlen, _, _) ->
    yystate(22, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [9|Ics], Line, Tlen, _, _) ->
    yystate(34, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(34, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,34};
yystate(33, [46|Ics], Line, Tlen, _, _) ->
    yystate(29, Ics, Line, Tlen+1, 9, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(37, Ics, Line, Tlen+1, 9, Tlen);
yystate(33, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line,33};
yystate(32, [126|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [124|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [94|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [59|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [58|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [47|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [45|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [42|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [43|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [39|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [37|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [38|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [36|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [34|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [35|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [33|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [9|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 62 ->
    yystate(28, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(24, Ics, Line, Tlen+1, 11, Tlen);
yystate(32, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,32};
yystate(31, [61|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 10, Tlen);
yystate(31, [45|Ics], Line, Tlen, _, _) ->
    yystate(35, Ics, Line, Tlen+1, 10, Tlen);
yystate(31, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,31};
yystate(30, [32|Ics], Line, Tlen, _, _) ->
    yystate(30, Ics, Line, Tlen+1, 5, Tlen);
yystate(30, [10|Ics], Line, Tlen, _, _) ->
    yystate(30, Ics, Line+1, Tlen+1, 5, Tlen);
yystate(30, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,30};
yystate(29, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(29, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,29};
yystate(28, [124|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, [45|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, [42|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, [43|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 39 ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 47, C =< 90 ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(28, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line,28};
yystate(27, [62|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 10, Tlen);
yystate(27, [61|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 10, Tlen);
yystate(27, [60|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 10, Tlen);
yystate(27, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,27};
yystate(26, [32|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 7, Tlen);
yystate(26, [9|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 7, Tlen);
yystate(26, [10|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line+1, Tlen+1, 7, Tlen);
yystate(26, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,26};
yystate(25, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(21, Ics, Line+1, Tlen+1, Action, Alen);
yystate(25, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,25};
yystate(24, [126|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [124|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [94|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [59|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [58|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [47|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [45|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [42|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [43|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [39|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [37|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [38|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [36|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [34|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [35|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [33|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [9|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 62 ->
    yystate(28, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(24, Ics, Line, Tlen+1, 1, Tlen);
yystate(24, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line,24};
yystate(23, [61|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 10, Tlen);
yystate(23, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,23};
yystate(22, [59|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, [32|Ics], Line, Tlen, _, _) ->
    yystate(22, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, [9|Ics], Line, Tlen, _, _) ->
    yystate(22, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,22};
yystate(21, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line};
yystate(20, [95|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(20, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 96, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 0, Tlen);
yystate(20, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line,20};
yystate(19, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 8, Tlen);
yystate(19, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line,19};
yystate(18, [61|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(18, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,18};
yystate(17, [62|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 10, Tlen);
yystate(17, [46|Ics], Line, Tlen, _, _) ->
    yystate(41, Ics, Line, Tlen+1, 10, Tlen);
yystate(17, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 10, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(13, Ics, Line, Tlen+1, 10, Tlen);
yystate(17, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,17};
yystate(16, [73|Ics], Line, Tlen, _, _) ->
    yystate(12, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 72 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 74, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(16, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,16};
yystate(15, [69|Ics], Line, Tlen, _, _) ->
    yystate(19, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 68 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(15, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,15};
yystate(14, [10|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line+1, Tlen+1, 3, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(14, Ics, Line, Tlen+1, 3, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 11 ->
    yystate(14, Ics, Line, Tlen+1, 3, Tlen);
yystate(14, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line,14};
yystate(13, [46|Ics], Line, Tlen, _, _) ->
    yystate(41, Ics, Line, Tlen+1, 2, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(13, Ics, Line, Tlen+1, 2, Tlen);
yystate(13, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,13};
yystate(12, [69|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 68 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,12};
yystate(11, [80|Ics], Line, Tlen, _, _) ->
    yystate(15, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 79 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 81, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(11, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,11};
yystate(10, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line};
yystate(9, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(5, Ics, Line, Tlen+1, Action, Alen);
yystate(9, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,9};
yystate(8, [76|Ics], Line, Tlen, _, _) ->
    yystate(4, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 75 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 77, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(8, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,8};
yystate(7, [90|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [89|Ics], Line, Tlen, _, _) ->
    yystate(11, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 88 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(7, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,7};
yystate(6, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line};
yystate(5, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(5, Ics, Line, Tlen+1, Action, Alen);
yystate(5, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(1, Ics, Line+1, Tlen+1, Action, Alen);
yystate(5, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,5};
yystate(4, [68|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 67 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 69, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(4, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,4};
yystate(3, [84|Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 83 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 85, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 95, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(3, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,3};
yystate(2, [46|Ics], Line, Tlen, _, _) ->
    yystate(41, Ics, Line, Tlen+1, 10, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(13, Ics, Line, Tlen+1, 10, Tlen);
yystate(2, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,2};
yystate(1, [10|Ics], Line, Tlen, _, _) ->
    yystate(1, Ics, Line+1, Tlen+1, 6, Tlen);
yystate(1, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line,1};
yystate(0, [95|Ics], Line, Tlen, _, _) ->
    yystate(3, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [59|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [39|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [36|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [33|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 31 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 63, C =< 90 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 96, C =< 122 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 127 ->
    yystate(42, Ics, Line, Tlen+1, 11, Tlen);
yystate(0, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_0(TokenChars, TokenLine);
yyaction(1, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_1(TokenChars, TokenLine);
yyaction(2, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_2(TokenChars, TokenLine);
yyaction(3, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_3(TokenChars, TokenLine);
yyaction(4, _, _, _) ->
    yyaction_4();
yyaction(5, _, _, TokenLine) ->
    yyaction_5(TokenLine);
yyaction(6, _, _, TokenLine) ->
    yyaction_6(TokenLine);
yyaction(7, _, _, TokenLine) ->
    yyaction_7(TokenLine);
yyaction(8, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_8(TokenChars, TokenLine);
yyaction(9, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_9(TokenChars, TokenLine);
yyaction(10, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_10(TokenChars, TokenLine);
yyaction(11, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_11(TokenChars, TokenLine);
yyaction(12, _, _, _) ->
    yyaction_12();
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/2}).
-file("src/pant_lexer.xrl", 16).
yyaction_0(TokenChars, TokenLine) ->
     { token, { int, TokenLine, integer (TokenChars) } } .

-compile({inline,yyaction_1/2}).
-file("src/pant_lexer.xrl", 17).
yyaction_1(TokenChars, TokenLine) ->
     { token, { literal, TokenLine, literal (TokenChars) } } .

-compile({inline,yyaction_2/2}).
-file("src/pant_lexer.xrl", 18).
yyaction_2(TokenChars, TokenLine) ->
     { token, { float, TokenLine, to_float (TokenChars) } } .

-compile({inline,yyaction_3/2}).
-file("src/pant_lexer.xrl", 19).
yyaction_3(TokenChars, TokenLine) ->
     comment (TokenChars, TokenLine) .

-compile({inline,yyaction_4/0}).
-file("src/pant_lexer.xrl", 21).
yyaction_4() ->
     skip_token .

-compile({inline,yyaction_5/1}).
-file("src/pant_lexer.xrl", 22).
yyaction_5(TokenLine) ->
     { token, { newline, TokenLine } } .

-compile({inline,yyaction_6/1}).
-file("src/pant_lexer.xrl", 24).
yyaction_6(TokenLine) ->
     { token, { sep, TokenLine } } .

-compile({inline,yyaction_7/1}).
-file("src/pant_lexer.xrl", 25).
yyaction_7(TokenLine) ->
     { token, { where, TokenLine } } .

-compile({inline,yyaction_8/2}).
-file("src/pant_lexer.xrl", 27).
yyaction_8(TokenChars, TokenLine) ->
     { token, { yield_type, TokenLine, TokenChars } } .

-compile({inline,yyaction_9/2}).
-file("src/pant_lexer.xrl", 28).
yyaction_9(TokenChars, TokenLine) ->
     { token, { list_to_atom (TokenChars), TokenLine } } .

-compile({inline,yyaction_10/2}).
-file("src/pant_lexer.xrl", 29).
yyaction_10(TokenChars, TokenLine) ->
     { token, operator (TokenChars, TokenLine) } .

-compile({inline,yyaction_11/2}).
-file("src/pant_lexer.xrl", 30).
yyaction_11(TokenChars, TokenLine) ->
     { token, keyword (TokenChars, TokenLine) } .

-compile({inline,yyaction_12/0}).
-file("src/pant_lexer.xrl", 32).
yyaction_12() ->
     skip_token .

-file("/usr/lib/erlang/lib/parsetools-2.1.8/include/leexinc.hrl", 313).
